package main

import (
  "encoding/json"
  "log"
  "net/http"
  "sync"
)

func replyJSONContent(w http.ResponseWriter, r *http.Request,
  status int, resp *todoResponse) {

  body, err := json.Marshal(resp)
  if err != nil {
    replyError(w, r, http.StatusInternalServerError, err.Error())
    return
  }

  w.Header().Set("Content-Type", "application/json")
  w.WriteHeader(status)
  w.Write(body)
}

func replyTextContent(w http.ResponseWriter, r *http.Request,
  status int, content string) {

  w.Header().Set("Content-Type", "text/plain")
  w.WriteHeader(status)
  w.Write([]byte(content))
}

func replyError(w http.ResponseWriter, r *http.Request,
  status int, message string) {

  log.Printf("%s %s: Error: %d %s", r.URL, r.Method, status, message)
  http.Error(w, http.StatusText(status), status)
}

func newMux(todoFile string) http.Handler {
  m := http.NewServeMux()
  mu := &sync.Mutex{}

  m.HandleFunc("/", rootHandler)

  t := todoRouter(todoFile, mu)

  m.Handle("/todo", http.StripPrefix("/todo", t))
  m.Handle("/todo/", http.StripPrefix("/todo/", t))

  return m
}
